Version 0.2.0
-------------

- First minor release with a semi-stable features (see below) and their documentations.
- Exploratory Data Analysis.
- Doc level Label Analysis.
- Clustering.
- Preprocessing functions.
- Partial MWEs.
- Tets.


Version 0.1.0
-------------

- Initial release with limited feats.
- Do not install this version.
